@@ -8,7 +8,7 @@
  * does it submit to any jurisdiction.
  */
 
-/// @author SimonSmart
+/// @author Simon Smart
 /// @date   Dec 2018
 
 #ifndef eckit_TmpDir_h
@@ -24,7 +24,9 @@ namespace eckit {
 
 class TmpDir : public PathName, private NonCopyable {
 public:
-    TmpDir();
+    TmpDir(const char* base=nullptr);
+
+    TmpDir(TmpDir&& rhs);
 
     ~TmpDir() noexcept(false);
 };
