@@ -20,6 +20,7 @@
 #include "eckit/config/Resource.h"
 #include "eckit/filesystem/PathName.h"
 #include "eckit/io/DataHandle.h"
+#include "eckit/mpi/ParallelGroup.h"
 #include "eckit/mpi/ParallelRequest.h"
 #include "eckit/mpi/ParallelStatus.h"
 #include "eckit/runtime/Main.h"
@@ -94,7 +95,7 @@ static MPI_Datatype PARALLEL_TWO_LONG_LONG() {
     return mpi_datatype;
 }
 
-}
+}  // namespace
 
 
 // define MPI_LONG_LONG if not existing to avoid compilation errors
@@ -132,7 +133,7 @@ static MPI_Datatype toType(Data::Code code) {
         /*[Data::LONG_LONG]            = */ MPI_LONG_LONG,
         /*[Data::TWO_LONG]             = */ PARALLEL_TWO_LONG(),
         /*[Data::TWO_LONG_LONG]        = */ PARALLEL_TWO_LONG_LONG(),
-        };
+    };
     return mpi_datatype_[code];
 }
 
@@ -327,6 +328,13 @@ std::string Parallel::processorName() const {
     return hostname;
 }
 
+size_t Parallel::remoteSize() const {
+    int s;
+    MPI_CALL(MPI_Comm_remote_size(comm_, &s));
+    return ((size_t)s);
+}
+
+
 void Parallel::barrier() const {
     MPI_CALL(MPI_Barrier(comm_));
 }
@@ -419,6 +427,10 @@ int Parallel::undefined() const {
     return MPI_UNDEFINED;
 }
 
+int Parallel::procNull() const {
+    return MPI_PROC_NULL;
+}
+
 size_t Parallel::getCount(Status& st, Data::Code type) const {
     int count = 0;
 
@@ -485,6 +497,29 @@ void Parallel::scatterv(const void* sendbuf, const int sendcounts[], const int d
                           recvbuf, int(recvcount), mpitype, int(root), comm_));
 }
 
+  void Parallel::reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code op, size_t root) const {
+    ASSERT(count < size_t(std::numeric_limits<int>::max()));
+
+    MPI_Datatype mpitype = toType(type);
+    MPI_Op mpiop         = toOp(op);
+    ;
+
+    MPI_CALL(MPI_Reduce(const_cast<void*>(sendbuf), recvbuf, int(count), mpitype, mpiop, int(root), comm_));
+}
+
+void Parallel::reduceInPlace(void* sendrecvbuf, size_t count, Data::Code type, Operation::Code op, size_t root) const {
+    ASSERT(count < size_t(std::numeric_limits<int>::max()));
+
+    MPI_Datatype mpitype = toType(type);
+    MPI_Op mpiop         = toOp(op);
+
+    if ( rank() == root ) {
+      MPI_CALL(MPI_Reduce(MPI_IN_PLACE, sendrecvbuf, int(count), mpitype, mpiop, int(root), comm_));
+    } else {
+      MPI_CALL(MPI_Reduce(sendrecvbuf, sendrecvbuf, int(count), mpitype, mpiop, int(root), comm_));
+    }
+}
+
 void Parallel::allReduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type, Operation::Code op) const {
     ASSERT(count < size_t(std::numeric_limits<int>::max()));
 
@@ -595,6 +630,20 @@ Request Parallel::iSend(const void* send, size_t count, Data::Code type, int des
     return req;
 }
 
+Status Parallel::sendReceiveReplace(void* sendrecv, size_t count, Data::Code type,
+				    int dest, int sendtag, int source, int recvtag) const {
+    ASSERT(count < size_t(std::numeric_limits<int>::max()));
+
+    MPI_Datatype mpitype = toType(type);
+
+    Status status = createStatus();
+
+    MPI_CALL(MPI_Sendrecv_replace(sendrecv, int(count), mpitype,
+				  dest, sendtag, source, recvtag, comm_, toStatus(status)));
+
+    return status;
+}
+
 Comm& Parallel::split(int color, const std::string& name) const {
 
     if (hasComm(name.c_str())) {
@@ -631,6 +680,39 @@ Request Parallel::request(int request) const {
     return Request(new ParallelRequest(MPI_Request_f2c(request)));
 }
 
+Group Parallel::group(int group) const {
+    return Group(new ParallelGroup(MPI_Group_f2c(group)));
+}
+
+Group Parallel::group() const {
+    MPI_Group g;
+    MPI_CALL(MPI_Comm_group(comm_, &g));
+    return Group(new ParallelGroup(g));
+}
+
+Group Parallel::remoteGroup() const {
+    MPI_Group g;
+    MPI_CALL(MPI_Comm_remote_group(comm_, &g));
+    return Group(new ParallelGroup(g));
+}
+
+Comm& Parallel::create(const Group& group, const std::string& name) const {
+    MPI_Comm new_mpi_comm;
+    MPI_CALL(MPI_Comm_create(comm_, dynamic_cast<const ParallelGroup&>(*group.content_).group_, &new_mpi_comm));
+    Comm* newcomm = new Parallel(name, new_mpi_comm, true);
+    addComm(name.c_str(), newcomm);
+    return *newcomm;
+};
+
+Comm& Parallel::create(const Group& group, int tag, const std::string& name) const {
+    MPI_Comm new_mpi_comm;
+    MPI_CALL(MPI_Comm_create_group(comm_, dynamic_cast<const ParallelGroup&>(*group.content_).group_, tag, &new_mpi_comm));
+    Comm* newcomm = new Parallel(name, new_mpi_comm, true);
+    addComm(name.c_str(), newcomm);
+    return *newcomm;
+};
+
+
 MPI_Request* Parallel::toRequest(Request& req) {
     return &(req.as<ParallelRequest>().request_);
 }
