@@ -38,6 +38,8 @@ protected:  // methods
     virtual eckit::mpi::Comm* self() const override;
 
     virtual std::string processorName() const override;
+    
+    virtual size_t remoteSize() const override;
 
     virtual void barrier() const override;
 
@@ -61,6 +63,8 @@ protected:  // methods
 
     virtual int undefined() const override;
 
+    virtual int procNull() const override;
+
     virtual size_t getCount(Status& st, Data::Code type) const override;
 
     virtual void broadcast(void* buffer, size_t count, Data::Code type, size_t root) const override;
@@ -77,6 +81,12 @@ protected:  // methods
     virtual void scatterv(const void* sendbuf, const int sendcounts[], const int displs[], void* recvbuf,
                           size_t recvcount, Data::Code type, size_t root) const override;
 
+    virtual void reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type,
+			Operation::Code op, size_t root) const override;
+
+    virtual void reduceInPlace(void* sendrecvbuf, size_t count, Data::Code type,
+			       Operation::Code op, size_t root) const override;
+
     virtual void allReduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code type,
                            Operation::Code op) const override;
 
@@ -104,6 +114,9 @@ protected:  // methods
 
     virtual Request iSend(const void* send, size_t count, Data::Code type, int dest, int tag) const override;
 
+    virtual Status sendReceiveReplace(void* sendrecv, size_t count, Data::Code type,
+				      int dest, int sendtag, int source, int recvtag) const override;
+
     virtual eckit::SharedBuffer broadcastFile(const eckit::PathName& filepath, size_t root) const override;
 
     virtual Comm& split(int color, const std::string& name) const override;
@@ -115,6 +128,16 @@ protected:  // methods
     virtual Status status() const override { return createStatus(); }
 
     virtual Request request(int) const override;
+    
+    virtual Group group(int) const override;
+    
+    virtual Group group() const override;
+    
+    virtual Group remoteGroup() const override;
+
+    virtual Comm& create(const Group&, const std::string& name) const override;
+
+    virtual Comm& create(const Group&, int tag, const std::string& name) const override;
 
     virtual int communicator() const override;
 
@@ -132,6 +155,8 @@ public:
     MPI_Comm MPIComm() const;
 
 private:  // methods
+    friend class ParallelGroup; // Groups should not call free if mpi has been finalized. Hence PrallelGroup needs to query finalized()
+    
     static void initialize();
 
     static void finalize();
