@@ -18,36 +18,33 @@
 
 namespace eckit {
 
-class ResizableBuffer;
+class Buffer;
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class ResizableMemoryStream : public Stream {
 public:
+    ResizableMemoryStream(Buffer&);
 
-    ResizableMemoryStream(ResizableBuffer&);
+    ~ResizableMemoryStream();
 
-	~ResizableMemoryStream();
+    virtual long read(void*, long) override;
+    virtual long write(const void*, long) override;
+    virtual void rewind() override;
 
-	virtual long read(void*,long);
-	virtual long write(const void*,long);
-	virtual void rewind();
-
-	virtual std::string name() const;
+    virtual std::string name() const override;
 
     size_t position() const;
 
-private: // members
+private:  // members
+    Buffer& buffer_;
 
-    ResizableBuffer& buffer_;
-
-    bool           read_;
-    size_t         position_;
+    size_t position_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 
 #endif
