@@ -46,7 +46,7 @@ namespace system {
 //----------------------------------------------------------------------------------------------------------------------
 
 static std::string path_from_libhandle(const std::string& libname, void* handle) {
-#ifdef eckit_HAVE_DLINFO
+#if eckit_HAVE_DLINFO
     char path[PATH_MAX];
     if (::dlinfo(handle, RTLD_DI_ORIGIN, path) < 0) {
         std::ostringstream ss;
@@ -254,26 +254,26 @@ public:  // methods
     }
 
     bool unloadPlugin(const std::string& name) {
-            Plugin* plugin = lookupPlugin(name);
-            if(plugin) {
-                plugin->finalise();
-                void* handle = plugin->handle();
-                if(handle) {
-                    ::dlerror();  // clear error
-                    int err = ::dlclose(handle);
-                    if (err) {
-                        std::ostringstream ss;
-                        ss << "Failed system call to ::dlclose() for plugin " << name << " - " << ::dlerror();
-                        throw FailedSystemCall(ss.str().c_str(), Here());
-                    }
-                    return true;
+        Plugin* plugin = lookupPlugin(name);
+        if (plugin) {
+            plugin->finalise();
+            void* handle = plugin->handle();
+            if (handle) {
+                ::dlerror();  // clear error
+                int err = ::dlclose(handle);
+                if (err) {
+                    std::ostringstream ss;
+                    ss << "Failed system call to ::dlclose() for plugin " << name << " - " << ::dlerror();
+                    throw FailedSystemCall(ss.str().c_str(), Here());
                 }
+                return true;
             }
-            return false;
+        }
+        return false;
     }
 
     void initPlugin(Plugin* plugin) {
-        if( ! is_plugin_initialized_[plugin->name()] ) {
+        if (!is_plugin_initialized_[plugin->name()]) {
             Log::debug() << "Initializing plugin [" << plugin->name() << "]" << std::endl;
             plugin->init();
             is_plugin_initialized_[plugin->name()] = true;
@@ -326,7 +326,7 @@ public:  // methods
                     LocalConfiguration manifest = conf.getSubConfiguration("plugin");
                     Log::debug() << "Loaded plugin manifest " << manifest << std::endl;
                     std::string name              = manifest.getString("name");
-                    std::string namespce         = manifest.getString("namespace");
+                    std::string namespce          = manifest.getString("namespace");
                     std::string fullQualifiedName = namespce + "." + name;
                     if (manifests.find(fullQualifiedName) == manifests.end()) {
                         manifests[fullQualifiedName] = manifest;
@@ -381,7 +381,7 @@ public:  // methods
         AutoLock<Mutex> lockme(mutex_);
         Log::debug() << "Registered plugin [" << name << "] with library [" << libname << "]" << std::endl;
         ASSERT(plugins_.find(name) == plugins_.end());
-        plugins_[name] = libname;
+        plugins_[name]               = libname;
         is_plugin_initialized_[name] = false;
     }
 
@@ -426,6 +426,13 @@ const Library& LibraryManager::lookup(const std::string& name) {
     return LibraryRegistry::instance().lookup(name);
 }
 
+const Plugin& LibraryManager::lookupPlugin(const std::string& name) {
+    Plugin * plugin = LibraryRegistry::instance().lookupPlugin(name);
+    if(plugin)
+        return *plugin;
+    throw eckit::BadValue("Plugin " + name + " not loaded");
+}
+
 void* LibraryManager::loadLibrary(const std::string& libname) {
     return LibraryRegistry::instance().loadDynamicLibrary(libname);
 }
